Package: inlpubs
Title: USGS INL Project Office Publications
Version: 1.4.0
Authors@R: c(
    person(given = c("Jason", "C."),
           family = "Fisher",
           role = c("aut", "cre"),
           email = "jfisher@usgs.gov",
           comment = c(ORCID = "0000-0001-9032-8912")),
    person(given = c("Kerri", "C."),
           family = "Treinen",
           role = "aut",
           email = "ktreinen@usgs.gov",
           comment = c(ORCID = "0000-0003-0645-6810")),
    person(given = c("Allison", "R."),
           family = "Trcka",
           role = "aut",
           email = "atrcka@usgs.gov",
           comment = c(ORCID = "0000-0001-8498-4737")))
Description: Provides bibliographic information and term-frequency text analysis
    tools for publications of the U.S. Geological Survey (USGS) Idaho National
    Laboratory (INL) Project Office. Includes datasets of publications, authors,
    and term frequencies, along with functions to search terms, build word
    clouds, and extract text and cover images from publication documents.
Depends: R (>= 4.1)
Imports: checkmate, knitr, kableExtra, parallel, stats, stringi, tm,
        utils
Suggests: callr, chromote, cli, connectapi, covr, cyclocomp, graphics,
        htmltools, htmlwidgets, jsonlite, lintr, magick, markdown,
        pdftools (>= 2.0), pkgbuild, pkgdown, pkgload, png, rcmdcheck,
        reactable, renv, rmarkdown, rsconnect, RWeka, tesseract,
        textutils, tinytest, webshot2, wordcloud2
License: CC0
URL: https://rconnect.usgs.gov/INLPO/inlpubs-main/,
        https://code.usgs.gov/inl/inlpubs
BugReports: https://code.usgs.gov/inl/inlpubs/-/issues
Copyright: This software is in the public domain because it contains
        materials that originally came from the United States
        Geological Survey (USGS), an agency of the United States
        Department of Interior. For more information, see the official
        USGS copyright policy at
        https://www.usgs.gov/information-policies-and-instructions/copyrights-and-credits
Encoding: UTF-8
SystemRequirements: Complete functionality necessitates Amazon Corretto
        (win), and default-jre, pandoc, libxml2-dev,
        libpoppler-cpp-dev, libmagick++-dev, optipng, libtesseract-dev,
        libleptonica-dev, tesseract-ocr-eng (deb)
LazyData: true
LazyDataCompression: xz
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-06 22:02:00 UTC; jfisher
Author: Jason C. Fisher [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9032-8912>),
  Kerri C. Treinen [aut] (ORCID: <https://orcid.org/0000-0003-0645-6810>),
  Allison R. Trcka [aut] (ORCID: <https://orcid.org/0000-0001-8498-4737>)
Maintainer: Jason C. Fisher <jfisher@usgs.gov>
Repository: CRAN
Date/Publication: 2026-07-06 22:40:02 UTC
Built: R 4.6.0; ; 2026-07-06 23:43:41 UTC; unix
