# Generated by roxygen2: do not edit by hand

export(add_content)
export(filter_data_list)
export(get_pdf_image)
export(get_pdf_text)
export(get_person)
export(make_webpages)
export(make_wordcloud)
export(mine_text)
export(plot_pubs)
export(search_terms)
