Logo image files (man/figures/logo.ai, man/figures/logo.svg, and pkgdown/favicon/*.png) are a derivative of the [Documents_icon_-_noun_project_5020.svg] file, accessed on 2023-08-14.

* **File URL:** <https://upload.wikimedia.org/wikipedia/commons/6/68/Documents_icon_-_noun_project_5020.svg>

* **Attribution:** Dmitry Baranovskiy from The Noun Project, Creative Commons Attribution 3.0 Unported <https://creativecommons.org/licenses/by/3.0/deed.en> license.

[Documents_icon_-_noun_project_5020.svg]: https://commons.wikimedia.org/wiki/File:Documents_icon_-_noun_project_5020.svg
